"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Statement = /** @class */ (function () {
    function Statement() {
        this.operation = "";
        this.table = "";
        this.text = "";
        this.values = [];
    }
    Statement.prototype.join = function (table, fields, type) {
        if (type === void 0) { type = "INNER"; }
        var expression = Object.entries(fields).map(function (v, k) { return v[0] + " = " + v[1]; });
        this.text += " " + type + " JOIN " + table + " ON " + expression.join(' AND ');
        return this;
    };
    Statement.prototype.where = function (fields, operator, separator) {
        var _this = this;
        if (operator === void 0) { operator = '='; }
        if (separator === void 0) { separator = 'AND'; }
        var expression = Object.keys(fields).map(function (v, k) { return v + " " + operator + " $" + (k + _this.values.length + 1); });
        this.values = this.values.concat(Object.values(fields));
        if (expression.length > 1) {
            this.text += " WHERE (" + expression.join(" " + separator + " ") + ")";
        }
        else {
            this.text += " WHERE " + expression.join(" " + separator + " ");
        }
        return this;
    };
    Statement.prototype.and = function (fields, operator, separator) {
        var _this = this;
        if (operator === void 0) { operator = '='; }
        if (separator === void 0) { separator = 'AND'; }
        var expression = Object.keys(fields).map(function (v, k) { return v + " " + operator + " $" + (k + _this.values.length + 1); });
        this.values = this.values.concat(Object.values(fields));
        if (expression.length > 1) {
            this.text += " AND (" + expression.join(" " + separator + " ") + ")";
        }
        else {
            this.text += " AND " + expression.join(" " + separator + " ");
        }
        return this;
    };
    Statement.prototype.or = function (fields, operator, separator) {
        var _this = this;
        if (operator === void 0) { operator = '='; }
        if (separator === void 0) { separator = 'AND'; }
        var expression = Object.keys(fields).map(function (v, k) { return v + " " + operator + " $" + (k + _this.values.length + 1); });
        this.values = this.values.concat(Object.values(fields));
        if (expression.length > 1) {
            this.text += " OR (" + expression.join(" " + separator + " ") + ")";
        }
        else {
            this.text += " OR " + expression.join(" " + separator + " ");
        }
        return this;
    };
    Statement.prototype.groupby = function (columns) {
        if (!Array.isArray(columns)) {
            columns = [columns];
        }
        this.text += " GROUB BY " + columns.join(', ');
        return this;
    };
    Statement.prototype.having = function (fields, operator, separator) {
        var _this = this;
        if (operator === void 0) { operator = '='; }
        if (separator === void 0) { separator = 'AND'; }
        var expression = Object.keys(fields).map(function (v, k) { return v + " " + operator + " $" + (k + _this.values.length + 1); });
        this.values = this.values.concat(Object.values(fields));
        this.text += " HAVING " + expression.join(" " + separator + " ");
        return this;
    };
    Statement.prototype.orderby = function (columns) {
        if (!Array.isArray(columns)) {
            columns = [columns];
        }
        this.text += " ORDER BY " + columns.join(', ');
        return this;
    };
    Statement.prototype.returning = function (columns) {
        if (!Array.isArray(columns)) {
            columns = [columns];
        }
        this.text += " RETURNING " + columns.join(', ');
        return this;
    };
    return Statement;
}());
exports.Statement = Statement;
function select(table, columns) {
    if (!Array.isArray(columns)) {
        columns = [columns];
    }
    var statement = new Statement();
    statement.operation = "SELECT";
    statement.table = table;
    statement.text = "SELECT " + columns.join(', ') + " FROM " + table;
    return statement;
}
exports.select = select;
function insert(table, fields) {
    var columns = Object.keys(fields);
    var values = Object.values(fields).map(function (v, k) { return "$" + (k + 1); });
    var statement = new Statement();
    statement.operation = "INSERT";
    statement.table = table;
    statement.values = Object.values(fields);
    statement.text = "INSERT INTO " + table + " (" + columns.join(", ") + ") VALUES (" + values.join(", ") + ")";
    return statement;
}
exports.insert = insert;
function update(table, fields) {
    var columns = Object.keys(fields).map(function (v, k) { return v + " = $" + (k + 1); });
    var statement = new Statement();
    statement.operation = "UPDATE";
    statement.table = table;
    statement.values = Object.values(fields);
    statement.text = "UPDATE " + table + " SET " + columns.join(", ");
    return statement;
}
exports.update = update;
function deletes(table) {
    var statement = new Statement();
    statement.operation = "DELETE";
    statement.table = table;
    statement.text = "DELETE FROM " + table;
    return statement;
}
exports.deletes = deletes;
//# sourceMappingURL=index.js.map